| Title: | Strongest Neighbor Coherence |
|---|---|
| Description: | Computes Strongest Neighbor Coherence (SNC), a structural diagnostic that replaces Cronbach's alpha using top-k correlation structure. |
| Authors: | Kevin E. Wells [aut, cre] |
| Maintainer: | Kevin E. Wells <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-11 06:59:53 UTC |
| Source: | https://github.com/theotherdrwells/snc |
Prints summary output for an object of class "snc".
## S3 method for class 'snc' print(x, ...)## S3 method for class 'snc' print(x, ...)
x |
An object of class |
... |
Ignored. |
Computes Strongest Neighbor Coherence (SNC), a rotation-free structural diagnostic that evaluates how well each item aligns with its top-k most strongly correlated neighbors.
snc(R, k = 2, factors = NULL, digits = 3)snc(R, k = 2, factors = NULL, digits = 3)
R |
A square item correlation matrix (symmetric, 1s on the diagonal). |
k |
Integer. Number of strongest neighbors to use for each item (default = 2). |
factors |
Optional. A vector of factor assignments for items, used to compute group-level means. |
digits |
Number of decimal places to round to (default = 3). |
An object of class "snc" with:
Mean SNC value across all items
A data frame of item-level SNC values
(Optional) A data frame of factor-level mean SNC values
R <- matrix(c(1, .6, .3, .6, 1, .5, .3, .5, 1), 3, 3) rownames(R) <- colnames(R) <- c("Item1", "Item2", "Item3") snc(R)R <- matrix(c(1, .6, .3, .6, 1, .5, .3, .5, 1), 3, 3) rownames(R) <- colnames(R) <- c("Item1", "Item2", "Item3") snc(R)